import { ref } from 'vue';

const statusMap = {
    // 定位成功
    0: 'BMAP_STATUS_SUCCESS',
    // 定位超时
    8: 'ERR_POSITION_TIMEOUT',
    // 定位不可用
    2: 'ERR_POSITION_UNAVAILABLE',
    // 没有权限，定位被拒绝
    6: 'ERR_PERMISSION_DENIED'
};
function useBrowserLocation(options, cal) {
    options = options || {};
    const location = ref({});
    const isLoading = ref(true);
    const isError = ref(false);
    const status = ref();
    const init = () => {
        options.SDKLocation = options.enableSDKLocation;
        new Promise((resolve, reject) => {
            isLoading.value = true;
            const geolocation = new BMapGL.Geolocation();
            geolocation.getCurrentPosition(function (res) {
                const _status = geolocation.getStatus();
                status.value = statusMap[_status];
                if (_status === window['BMAP_STATUS_SUCCESS']) {
                    const { address, accuracy, point } = res;
                    resolve({
                        accuracy,
                        point,
                        address
                    });
                }
                else {
                    reject();
                }
            }, options);
        })
            .then((res) => {
            isError.value = false;
            location.value = res;
            cal && cal(location);
        })
            .catch(() => {
            isError.value = true;
        })
            .finally(() => {
            isLoading.value = false;
        });
    };
    return {
        get: init,
        isLoading,
        isError,
        status,
        location
    };
}

export { useBrowserLocation };
