import { Point } from '../utils';
export declare enum CoordinatesFromType {
    /**
     *  WGS84坐标（GPS标准坐标）
     */
    'COORDINATES_WGS84' = 1,
    /**
     *  WGS84的平面墨卡托坐标（搜狗地图坐标）
     */
    'COORDINATES_WGS84_MC' = 2,
    /**
     * GCJ02坐标(火星坐标)，即高德地图、腾讯地图、谷歌坐标和MapABC等地图使用的坐标；
     */
    'COORDINATES_GCJ02' = 3,
    /**
     *  GCJ02的平面墨卡托坐标（火星坐标对应的墨卡托平面坐标）
     */
    'COORDINATES_GCJ02_MC' = 4,
    /**
     *  百度地图采用的经纬度坐标（bd09ll）
     */
    'COORDINATES_BD09' = 5,
    /**
     * 百度地图采用的墨卡托平面坐标（bd09mc）
     */
    'COORDINATES_BD09_MC' = 6,
    /**
     * 图吧地图坐标
     */
    'COORDINATES_MAPBAR' = 7,
    /**
     * 51地图坐标
     */
    'COORDINATES_51' = 8
}
export declare enum CoordinatesToType {
    /**
     * GCJ02坐标(火星坐标)，即高德地图、腾讯地图、谷歌坐标和MapABC等地图使用的坐标；
     */
    'COORDINATES_GCJ02' = 3,
    /**
     * 百度地图采用的经纬度坐标（bd09ll）
     */
    'COORDINATES_BD09' = 5,
    /**
     * 百度地图采用的墨卡托平面坐标（bd09mc）
     */
    'COORDINATES_BD09_MC' = 6
}
export declare type UsePointConvertorStatus = 0 | 1 | 4 | 21 | 22 | 24 | 25 | 26;
export declare function usePointConvertor(): {
    convert: (points: Point[], from: CoordinatesFromType, to: CoordinatesToType) => void;
    result: import("vue").Ref<Point[] | undefined>;
    isLoading: import("vue").Ref<boolean>;
    isError: import("vue").Ref<boolean>;
    status: import("vue").Ref<UsePointConvertorStatus | undefined>;
};
