import { type Point } from '../utils';
export declare type UseTrackAnimationOptions = {
    /**
     * 动画持续时常，单位ms
     * @default 10000
     */
    duration?: number;
    /**
     * 动画开始延迟
     * @default 0
     */
    delay?: number;
    /**
     * 是否在动画结束后总览视图缩放（调整地图到能看到整个轨迹的视野），默认开启
     * @default true
     */
    overallView?: boolean;
    /**
     * 设置动画中的地图倾斜角度，默认55度
     * @default 55
     */
    tilt?: number;
    /**
     * 设置动画中的缩放级别，默认会根据轨迹情况调整到一个合适的级别
     * @default auto
     */
    zoom?: number;
};
declare type AnimationStatus = 'PLAYING' | 'STOPPING' | 'INITIAL';
/**
 * 轨迹动画
 * @param {any} map 地图组件实例引用
 * @param {UseTrackAnimationOptions} options 轨迹动画配置
 * @returns { setPath, start, stop}
 */
export declare function useTrackAnimation(map: any, options?: UseTrackAnimationOptions): {
    /**
     * 设置路径动画路径
     */
    setPath: (path: Point[]) => void;
    /**
     * 开始动画
     */
    start: () => void;
    /**
     * 暂停动画
     */
    stop: () => void;
    /**
     * 取消动画
     */
    cancel: () => void;
    /**
     * 继续播放动画
     */
    proceed: () => void;
    /**
     * 动画状态
     */
    status: import("vue").Ref<AnimationStatus>;
};
export {};
